@@ -9,21 +9,6 @@ from requests import Response
 log = logging.getLogger(__name__)
 
 
-def get_checksum(img_url: str) -> str:
-    return img_url.split('/')[-2]
-
-
-def get_key(img_url: str) -> str:
-    return img_url.split('?')[1].split('&')[1].split('=')[1]
-
-
-def get_seed(checksum: str, expiry_key: int) -> str:
-    for num in expiry_key:
-        if int(num) != 0:
-            checksum = checksum[-int(num):] + checksum[:len(checksum)-int(num)]
-    return checksum
-
-
 def retry() -> Callable[..., Response]:
     def _retry(func):
         @wraps(func)
